@@ -1,4 +1,4 @@
-#!/usr/bin/perl 
+#!/usr/bin/perl
 
 # 
 # spfquery: Command-line tool for performing SPF queries
@@ -16,7 +16,7 @@ domain's SPF policy
 
 =head1 VERSION
 
-2.501
+version 3.20240923
 
 =head1 SYNOPSIS
 
@@ -145,7 +145,7 @@ Print out debug information.
 Several options that were supported by earlier versions of B<spfquery> are
 considered black magic (i.e. potentially dangerous for the innocent user) and
 are thus disabled by default.  If the L<B<Mail::SPF::BlackMagic>> Perl module
-is installed, they may be enabled by specifying B<--enable-black-magic>.
+is installed (module currently not available), they may be enabled by specifying B<--enable-black-magic>.
 
 =over
 
@@ -626,8 +626,10 @@ if (
     exit(255);
 }
 
-if (defined($identity) and $identity eq '') {
-    STDERR->print("Error: Empty identities are not supported. See spfquery(1).\n");
+if (defined($identity) and $identity eq '' and defined $helo_identity) {
+    $identity = 'postmaster@' . $helo_identity;
+} elsif (defined($identity) and $identity eq '') {
+    STDERR->print("Error: Empty identities are not supported without specifying HELO.\n");
     exit(255);
 }
 
